ParserGenerator class

Parser Generator generates parser source code from a given grammar source code.

Constructors

ParserGenerator({required ParserGeneratorOptions options, required String source})

Properties

hashCode → int
The hash code for this object.
no setterinherited
options → ParserGeneratorOptions
Parser generator options.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
Source code of the grammar.
final

Methods

generate() → String
Generates parser source code and returns that code.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited